# coding: utf-8

"""
    VeeRoute.UD

    VeeRoute.UD API  # noqa: E501

    The version of the OpenAPI document: 2.8.161005
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from vrt_ud.api_client import ApiClient
from vrt_ud.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class ConfiguratorApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_cfg(self, name, configuration, **kwargs):  # noqa: E501
        """Configuration change.  # noqa: E501

        Changing the configuration by its name.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_cfg(name, configuration, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str name: (required)
        :param Configuration configuration: Configuration change request. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Configuration
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.create_cfg_with_http_info(name, configuration, **kwargs)  # noqa: E501

    def create_cfg_with_http_info(self, name, configuration, **kwargs):  # noqa: E501
        """Configuration change.  # noqa: E501

        Changing the configuration by its name.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_cfg_with_http_info(name, configuration, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str name: (required)
        :param Configuration configuration: Configuration change request. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Configuration, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'name',
            'configuration'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_cfg" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'name' is set
        if self.api_client.client_side_validation and ('name' not in local_var_params or  # noqa: E501
                                                        local_var_params['name'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `name` when calling `create_cfg`")  # noqa: E501
        # verify the required parameter 'configuration' is set
        if self.api_client.client_side_validation and ('configuration' not in local_var_params or  # noqa: E501
                                                        local_var_params['configuration'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `configuration` when calling `create_cfg`")  # noqa: E501

        if self.api_client.client_side_validation and ('name' in local_var_params and  # noqa: E501
                                                        len(local_var_params['name']) > 1000):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `name` when calling `create_cfg`, length must be less than or equal to `1000`")  # noqa: E501
        if self.api_client.client_side_validation and ('name' in local_var_params and  # noqa: E501
                                                        len(local_var_params['name']) < 1):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `name` when calling `create_cfg`, length must be greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'name' in local_var_params:
            path_params['name'] = local_var_params['name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'configuration' in local_var_params:
            body_params = local_var_params['configuration']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['ApiKeyAuth']  # noqa: E501

        return self.api_client.call_api(
            '/cfg/{name}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Configuration',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_cfg(self, name, **kwargs):  # noqa: E501
        """Configuration removal.  # noqa: E501

        Removing the configuration by its name.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_cfg(name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str name: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.delete_cfg_with_http_info(name, **kwargs)  # noqa: E501

    def delete_cfg_with_http_info(self, name, **kwargs):  # noqa: E501
        """Configuration removal.  # noqa: E501

        Removing the configuration by its name.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_cfg_with_http_info(name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str name: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'name'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_cfg" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'name' is set
        if self.api_client.client_side_validation and ('name' not in local_var_params or  # noqa: E501
                                                        local_var_params['name'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `name` when calling `delete_cfg`")  # noqa: E501

        if self.api_client.client_side_validation and ('name' in local_var_params and  # noqa: E501
                                                        len(local_var_params['name']) > 1000):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `name` when calling `delete_cfg`, length must be less than or equal to `1000`")  # noqa: E501
        if self.api_client.client_side_validation and ('name' in local_var_params and  # noqa: E501
                                                        len(local_var_params['name']) < 1):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `name` when calling `delete_cfg`, length must be greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'name' in local_var_params:
            path_params['name'] = local_var_params['name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['ApiKeyAuth']  # noqa: E501

        return self.api_client.call_api(
            '/cfg/{name}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def read_cfg(self, name, **kwargs):  # noqa: E501
        """Reading the configuration.  # noqa: E501

        Getting the configuration by its name.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.read_cfg(name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str name: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Configuration
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.read_cfg_with_http_info(name, **kwargs)  # noqa: E501

    def read_cfg_with_http_info(self, name, **kwargs):  # noqa: E501
        """Reading the configuration.  # noqa: E501

        Getting the configuration by its name.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.read_cfg_with_http_info(name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str name: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Configuration, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'name'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method read_cfg" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'name' is set
        if self.api_client.client_side_validation and ('name' not in local_var_params or  # noqa: E501
                                                        local_var_params['name'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `name` when calling `read_cfg`")  # noqa: E501

        if self.api_client.client_side_validation and ('name' in local_var_params and  # noqa: E501
                                                        len(local_var_params['name']) > 1000):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `name` when calling `read_cfg`, length must be less than or equal to `1000`")  # noqa: E501
        if self.api_client.client_side_validation and ('name' in local_var_params and  # noqa: E501
                                                        len(local_var_params['name']) < 1):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `name` when calling `read_cfg`, length must be greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'name' in local_var_params:
            path_params['name'] = local_var_params['name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['ApiKeyAuth']  # noqa: E501

        return self.api_client.call_api(
            '/cfg/{name}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Configuration',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def read_cfg_names(self, **kwargs):  # noqa: E501
        """Reading the configuration names.  # noqa: E501

        Getting the names list of all possible configurations.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.read_cfg_names(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[str]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.read_cfg_names_with_http_info(**kwargs)  # noqa: E501

    def read_cfg_names_with_http_info(self, **kwargs):  # noqa: E501
        """Reading the configuration names.  # noqa: E501

        Getting the names list of all possible configurations.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.read_cfg_names_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[str], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method read_cfg_names" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['ApiKeyAuth']  # noqa: E501

        return self.api_client.call_api(
            '/cfg', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[str]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_cfg(self, name, path, value, **kwargs):  # noqa: E501
        """Configuration parameter change.  # noqa: E501

        Changing the configuration parameter by a variable name.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_cfg(name, path, value, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str name: (required)
        :param str path: (required)
        :param str value: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Configuration
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.update_cfg_with_http_info(name, path, value, **kwargs)  # noqa: E501

    def update_cfg_with_http_info(self, name, path, value, **kwargs):  # noqa: E501
        """Configuration parameter change.  # noqa: E501

        Changing the configuration parameter by a variable name.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_cfg_with_http_info(name, path, value, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str name: (required)
        :param str path: (required)
        :param str value: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Configuration, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'name',
            'path',
            'value'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_cfg" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'name' is set
        if self.api_client.client_side_validation and ('name' not in local_var_params or  # noqa: E501
                                                        local_var_params['name'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `name` when calling `update_cfg`")  # noqa: E501
        # verify the required parameter 'path' is set
        if self.api_client.client_side_validation and ('path' not in local_var_params or  # noqa: E501
                                                        local_var_params['path'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `path` when calling `update_cfg`")  # noqa: E501
        # verify the required parameter 'value' is set
        if self.api_client.client_side_validation and ('value' not in local_var_params or  # noqa: E501
                                                        local_var_params['value'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `value` when calling `update_cfg`")  # noqa: E501

        if self.api_client.client_side_validation and ('name' in local_var_params and  # noqa: E501
                                                        len(local_var_params['name']) > 1000):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `name` when calling `update_cfg`, length must be less than or equal to `1000`")  # noqa: E501
        if self.api_client.client_side_validation and ('name' in local_var_params and  # noqa: E501
                                                        len(local_var_params['name']) < 1):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `name` when calling `update_cfg`, length must be greater than or equal to `1`")  # noqa: E501
        if self.api_client.client_side_validation and ('path' in local_var_params and  # noqa: E501
                                                        len(local_var_params['path']) > 1024):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `path` when calling `update_cfg`, length must be less than or equal to `1024`")  # noqa: E501
        if self.api_client.client_side_validation and ('path' in local_var_params and  # noqa: E501
                                                        len(local_var_params['path']) < 1):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `path` when calling `update_cfg`, length must be greater than or equal to `1`")  # noqa: E501
        if self.api_client.client_side_validation and ('value' in local_var_params and  # noqa: E501
                                                        len(local_var_params['value']) < 1):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `value` when calling `update_cfg`, length must be greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'name' in local_var_params:
            path_params['name'] = local_var_params['name']  # noqa: E501

        query_params = []
        if 'path' in local_var_params and local_var_params['path'] is not None:  # noqa: E501
            query_params.append(('path', local_var_params['path']))  # noqa: E501
        if 'value' in local_var_params and local_var_params['value'] is not None:  # noqa: E501
            query_params.append(('value', local_var_params['value']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['ApiKeyAuth']  # noqa: E501

        return self.api_client.call_api(
            '/cfg/{name}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Configuration',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    VeeRoute.UD

    VeeRoute.UD API  # noqa: E501

    The version of the OpenAPI document: 2.8.161005
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import vrt_ud
from vrt_ud.api.reports_api import ReportsApi  # noqa: E501
from vrt_ud.rest import ApiException


class TestReportsApi(unittest.TestCase):
    """ReportsApi unit test stubs"""

    def setUp(self):
        self.api = vrt_ud.api.reports_api.ReportsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_generate_report(self):
        """Test case for generate_report

        Generating the report by filter.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    VeeRoute.UD

    VeeRoute.UD API  # noqa: E501

    The version of the OpenAPI document: 2.8.161005
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from vrt_ud.configuration import Configuration


class DataLoadMultipartTask(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'file': 'file',
        'time_shift_hours': 'int',
        'save': 'bool'
    }

    attribute_map = {
        'file': 'file',
        'time_shift_hours': 'time_shift_hours',
        'save': 'save'
    }

    def __init__(self, file=None, time_shift_hours=0, save=True, local_vars_configuration=None):  # noqa: E501
        """DataLoadMultipartTask - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._file = None
        self._time_shift_hours = None
        self._save = None
        self.discriminator = None

        self.file = file
        if time_shift_hours is not None:
            self.time_shift_hours = time_shift_hours
        if save is not None:
            self.save = save

    @property
    def file(self):
        """Gets the file of this DataLoadMultipartTask.  # noqa: E501

        File contents.  # noqa: E501

        :return: The file of this DataLoadMultipartTask.  # noqa: E501
        :rtype: file
        """
        return self._file

    @file.setter
    def file(self, file):
        """Sets the file of this DataLoadMultipartTask.

        File contents.  # noqa: E501

        :param file: The file of this DataLoadMultipartTask.  # noqa: E501
        :type: file
        """
        if self.local_vars_configuration.client_side_validation and file is None:  # noqa: E501
            raise ValueError("Invalid value for `file`, must not be `None`")  # noqa: E501

        self._file = file

    @property
    def time_shift_hours(self):
        """Gets the time_shift_hours of this DataLoadMultipartTask.  # noqa: E501

        The times in the data will be shifted during loading for the specified time period in hours, and both positive and negative values are accepted.  # noqa: E501

        :return: The time_shift_hours of this DataLoadMultipartTask.  # noqa: E501
        :rtype: int
        """
        return self._time_shift_hours

    @time_shift_hours.setter
    def time_shift_hours(self, time_shift_hours):
        """Sets the time_shift_hours of this DataLoadMultipartTask.

        The times in the data will be shifted during loading for the specified time period in hours, and both positive and negative values are accepted.  # noqa: E501

        :param time_shift_hours: The time_shift_hours of this DataLoadMultipartTask.  # noqa: E501
        :type: int
        """

        self._time_shift_hours = time_shift_hours

    @property
    def save(self):
        """Gets the save of this DataLoadMultipartTask.  # noqa: E501

        Save the file after uploading to the server.  # noqa: E501

        :return: The save of this DataLoadMultipartTask.  # noqa: E501
        :rtype: bool
        """
        return self._save

    @save.setter
    def save(self, save):
        """Sets the save of this DataLoadMultipartTask.

        Save the file after uploading to the server.  # noqa: E501

        :param save: The save of this DataLoadMultipartTask.  # noqa: E501
        :type: bool
        """

        self._save = save

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DataLoadMultipartTask):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DataLoadMultipartTask):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    VeeRoute.UD

    VeeRoute.UD API  # noqa: E501

    The version of the OpenAPI document: 2.8.161005
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from vrt_ud.configuration import Configuration


class PredictorInsertTask(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'order': 'Order',
        'locations': 'list[AdvancedLocation]',
        'max_cost': 'int',
        'allow_to_update_order': 'bool'
    }

    attribute_map = {
        'order': 'order',
        'locations': 'locations',
        'max_cost': 'max_cost',
        'allow_to_update_order': 'allow_to_update_order'
    }

    def __init__(self, order=None, locations=None, max_cost=None, allow_to_update_order=False, local_vars_configuration=None):  # noqa: E501
        """PredictorInsertTask - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._order = None
        self._locations = None
        self._max_cost = None
        self._allow_to_update_order = None
        self.discriminator = None

        self.order = order
        self.locations = locations
        self.max_cost = max_cost
        if allow_to_update_order is not None:
            self.allow_to_update_order = allow_to_update_order

    @property
    def order(self):
        """Gets the order of this PredictorInsertTask.  # noqa: E501


        :return: The order of this PredictorInsertTask.  # noqa: E501
        :rtype: Order
        """
        return self._order

    @order.setter
    def order(self, order):
        """Sets the order of this PredictorInsertTask.


        :param order: The order of this PredictorInsertTask.  # noqa: E501
        :type: Order
        """
        if self.local_vars_configuration.client_side_validation and order is None:  # noqa: E501
            raise ValueError("Invalid value for `order`, must not be `None`")  # noqa: E501

        self._order = order

    @property
    def locations(self):
        """Gets the locations of this PredictorInsertTask.  # noqa: E501

        List of locations used in the order for window prediction.  # noqa: E501

        :return: The locations of this PredictorInsertTask.  # noqa: E501
        :rtype: list[AdvancedLocation]
        """
        return self._locations

    @locations.setter
    def locations(self, locations):
        """Sets the locations of this PredictorInsertTask.

        List of locations used in the order for window prediction.  # noqa: E501

        :param locations: The locations of this PredictorInsertTask.  # noqa: E501
        :type: list[AdvancedLocation]
        """
        if self.local_vars_configuration.client_side_validation and locations is None:  # noqa: E501
            raise ValueError("Invalid value for `locations`, must not be `None`")  # noqa: E501

        self._locations = locations

    @property
    def max_cost(self):
        """Gets the max_cost of this PredictorInsertTask.  # noqa: E501

        The maximum cost for which it is possible to insert an order.  # noqa: E501

        :return: The max_cost of this PredictorInsertTask.  # noqa: E501
        :rtype: int
        """
        return self._max_cost

    @max_cost.setter
    def max_cost(self, max_cost):
        """Sets the max_cost of this PredictorInsertTask.

        The maximum cost for which it is possible to insert an order.  # noqa: E501

        :param max_cost: The max_cost of this PredictorInsertTask.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and max_cost is None:  # noqa: E501
            raise ValueError("Invalid value for `max_cost`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                max_cost is not None and max_cost < 0):  # noqa: E501
            raise ValueError("Invalid value for `max_cost`, must be a value greater than or equal to `0`")  # noqa: E501

        self._max_cost = max_cost

    @property
    def allow_to_update_order(self):
        """Gets the allow_to_update_order of this PredictorInsertTask.  # noqa: E501

        This parameter allows updating the existing order with the specified ID.  # noqa: E501

        :return: The allow_to_update_order of this PredictorInsertTask.  # noqa: E501
        :rtype: bool
        """
        return self._allow_to_update_order

    @allow_to_update_order.setter
    def allow_to_update_order(self, allow_to_update_order):
        """Sets the allow_to_update_order of this PredictorInsertTask.

        This parameter allows updating the existing order with the specified ID.  # noqa: E501

        :param allow_to_update_order: The allow_to_update_order of this PredictorInsertTask.  # noqa: E501
        :type: bool
        """

        self._allow_to_update_order = allow_to_update_order

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PredictorInsertTask):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PredictorInsertTask):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    VeeRoute.UD

    VeeRoute.UD API  # noqa: E501

    The version of the OpenAPI document: 2.8.161005
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from vrt_ud.configuration import Configuration


class Trip(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'key': 'str',
        'trip_id': 'str',
        'assigned_shifts': 'list[AssignedShift]',
        'actions': 'list[TripAction]',
        'waitlist': 'list[str]'
    }

    attribute_map = {
        'key': 'key',
        'trip_id': 'trip_id',
        'assigned_shifts': 'assigned_shifts',
        'actions': 'actions',
        'waitlist': 'waitlist'
    }

    def __init__(self, key=None, trip_id=None, assigned_shifts=None, actions=None, waitlist=None, local_vars_configuration=None):  # noqa: E501
        """Trip - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._key = None
        self._trip_id = None
        self._assigned_shifts = None
        self._actions = None
        self._waitlist = None
        self.discriminator = None

        self.key = key
        if trip_id is not None:
            self.trip_id = trip_id
        self.assigned_shifts = assigned_shifts
        if actions is not None:
            self.actions = actions
        if waitlist is not None:
            self.waitlist = waitlist

    @property
    def key(self):
        """Gets the key of this Trip.  # noqa: E501

        Trip key, unique ID.  # noqa: E501

        :return: The key of this Trip.  # noqa: E501
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """Sets the key of this Trip.

        Trip key, unique ID.  # noqa: E501

        :param key: The key of this Trip.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and key is None:  # noqa: E501
            raise ValueError("Invalid value for `key`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                key is not None and len(key) > 1024):
            raise ValueError("Invalid value for `key`, length must be less than or equal to `1024`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                key is not None and len(key) < 1):
            raise ValueError("Invalid value for `key`, length must be greater than or equal to `1`")  # noqa: E501

        self._key = key

    @property
    def trip_id(self):
        """Gets the trip_id of this Trip.  # noqa: E501

        Internal ID of the trip with an order.  # noqa: E501

        :return: The trip_id of this Trip.  # noqa: E501
        :rtype: str
        """
        return self._trip_id

    @trip_id.setter
    def trip_id(self, trip_id):
        """Sets the trip_id of this Trip.

        Internal ID of the trip with an order.  # noqa: E501

        :param trip_id: The trip_id of this Trip.  # noqa: E501
        :type: str
        """

        self._trip_id = trip_id

    @property
    def assigned_shifts(self):
        """Gets the assigned_shifts of this Trip.  # noqa: E501

        Assigned shifts list.  # noqa: E501

        :return: The assigned_shifts of this Trip.  # noqa: E501
        :rtype: list[AssignedShift]
        """
        return self._assigned_shifts

    @assigned_shifts.setter
    def assigned_shifts(self, assigned_shifts):
        """Sets the assigned_shifts of this Trip.

        Assigned shifts list.  # noqa: E501

        :param assigned_shifts: The assigned_shifts of this Trip.  # noqa: E501
        :type: list[AssignedShift]
        """
        if self.local_vars_configuration.client_side_validation and assigned_shifts is None:  # noqa: E501
            raise ValueError("Invalid value for `assigned_shifts`, must not be `None`")  # noqa: E501

        self._assigned_shifts = assigned_shifts

    @property
    def actions(self):
        """Gets the actions of this Trip.  # noqa: E501

        List of actions witn orders.  # noqa: E501

        :return: The actions of this Trip.  # noqa: E501
        :rtype: list[TripAction]
        """
        return self._actions

    @actions.setter
    def actions(self, actions):
        """Sets the actions of this Trip.

        List of actions witn orders.  # noqa: E501

        :param actions: The actions of this Trip.  # noqa: E501
        :type: list[TripAction]
        """

        self._actions = actions

    @property
    def waitlist(self):
        """Gets the waitlist of this Trip.  # noqa: E501

        Keys list of orders, assigned, but not scheduled to the specified time.  # noqa: E501

        :return: The waitlist of this Trip.  # noqa: E501
        :rtype: list[str]
        """
        return self._waitlist

    @waitlist.setter
    def waitlist(self, waitlist):
        """Sets the waitlist of this Trip.

        Keys list of orders, assigned, but not scheduled to the specified time.  # noqa: E501

        :param waitlist: The waitlist of this Trip.  # noqa: E501
        :type: list[str]
        """

        self._waitlist = waitlist

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Trip):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Trip):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    VeeRoute.UD

    VeeRoute.UD API  # noqa: E501

    The version of the OpenAPI document: 2.8.161005
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from vrt_ud.configuration import Configuration


class MerchandiseLine(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'goods_name': 'str',
        'goods_unit_name': 'str',
        'goods_unit_price': 'float',
        'goods_amount': 'int',
        'goods_value': 'float',
        'vat_rate': 'str',
        'barcode': 'str',
        'fact_time': 'datetime'
    }

    attribute_map = {
        'goods_name': 'goods_name',
        'goods_unit_name': 'goods_unit_name',
        'goods_unit_price': 'goods_unit_price',
        'goods_amount': 'goods_amount',
        'goods_value': 'goods_value',
        'vat_rate': 'vat_rate',
        'barcode': 'barcode',
        'fact_time': 'fact_time'
    }

    def __init__(self, goods_name=None, goods_unit_name=None, goods_unit_price=None, goods_amount=None, goods_value=None, vat_rate='VAT0000', barcode=None, fact_time=None, local_vars_configuration=None):  # noqa: E501
        """MerchandiseLine - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._goods_name = None
        self._goods_unit_name = None
        self._goods_unit_price = None
        self._goods_amount = None
        self._goods_value = None
        self._vat_rate = None
        self._barcode = None
        self._fact_time = None
        self.discriminator = None

        self.goods_name = goods_name
        if goods_unit_name is not None:
            self.goods_unit_name = goods_unit_name
        self.goods_unit_price = goods_unit_price
        self.goods_amount = goods_amount
        if goods_value is not None:
            self.goods_value = goods_value
        self.vat_rate = vat_rate
        if barcode is not None:
            self.barcode = barcode
        if fact_time is not None:
            self.fact_time = fact_time

    @property
    def goods_name(self):
        """Gets the goods_name of this MerchandiseLine.  # noqa: E501

        Product name.  # noqa: E501

        :return: The goods_name of this MerchandiseLine.  # noqa: E501
        :rtype: str
        """
        return self._goods_name

    @goods_name.setter
    def goods_name(self, goods_name):
        """Sets the goods_name of this MerchandiseLine.

        Product name.  # noqa: E501

        :param goods_name: The goods_name of this MerchandiseLine.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and goods_name is None:  # noqa: E501
            raise ValueError("Invalid value for `goods_name`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                goods_name is not None and len(goods_name) > 1000):
            raise ValueError("Invalid value for `goods_name`, length must be less than or equal to `1000`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                goods_name is not None and len(goods_name) < 1):
            raise ValueError("Invalid value for `goods_name`, length must be greater than or equal to `1`")  # noqa: E501

        self._goods_name = goods_name

    @property
    def goods_unit_name(self):
        """Gets the goods_unit_name of this MerchandiseLine.  # noqa: E501

        Product unit name.  # noqa: E501

        :return: The goods_unit_name of this MerchandiseLine.  # noqa: E501
        :rtype: str
        """
        return self._goods_unit_name

    @goods_unit_name.setter
    def goods_unit_name(self, goods_unit_name):
        """Sets the goods_unit_name of this MerchandiseLine.

        Product unit name.  # noqa: E501

        :param goods_unit_name: The goods_unit_name of this MerchandiseLine.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                goods_unit_name is not None and len(goods_unit_name) > 1000):
            raise ValueError("Invalid value for `goods_unit_name`, length must be less than or equal to `1000`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                goods_unit_name is not None and len(goods_unit_name) < 1):
            raise ValueError("Invalid value for `goods_unit_name`, length must be greater than or equal to `1`")  # noqa: E501

        self._goods_unit_name = goods_unit_name

    @property
    def goods_unit_price(self):
        """Gets the goods_unit_price of this MerchandiseLine.  # noqa: E501

        Unit price.  # noqa: E501

        :return: The goods_unit_price of this MerchandiseLine.  # noqa: E501
        :rtype: float
        """
        return self._goods_unit_price

    @goods_unit_price.setter
    def goods_unit_price(self, goods_unit_price):
        """Sets the goods_unit_price of this MerchandiseLine.

        Unit price.  # noqa: E501

        :param goods_unit_price: The goods_unit_price of this MerchandiseLine.  # noqa: E501
        :type: float
        """
        if self.local_vars_configuration.client_side_validation and goods_unit_price is None:  # noqa: E501
            raise ValueError("Invalid value for `goods_unit_price`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                goods_unit_price is not None and goods_unit_price < 0):  # noqa: E501
            raise ValueError("Invalid value for `goods_unit_price`, must be a value greater than or equal to `0`")  # noqa: E501

        self._goods_unit_price = goods_unit_price

    @property
    def goods_amount(self):
        """Gets the goods_amount of this MerchandiseLine.  # noqa: E501

        Product amount.  # noqa: E501

        :return: The goods_amount of this MerchandiseLine.  # noqa: E501
        :rtype: int
        """
        return self._goods_amount

    @goods_amount.setter
    def goods_amount(self, goods_amount):
        """Sets the goods_amount of this MerchandiseLine.

        Product amount.  # noqa: E501

        :param goods_amount: The goods_amount of this MerchandiseLine.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and goods_amount is None:  # noqa: E501
            raise ValueError("Invalid value for `goods_amount`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                goods_amount is not None and goods_amount > 10000):  # noqa: E501
            raise ValueError("Invalid value for `goods_amount`, must be a value less than or equal to `10000`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                goods_amount is not None and goods_amount < 1):  # noqa: E501
            raise ValueError("Invalid value for `goods_amount`, must be a value greater than or equal to `1`")  # noqa: E501

        self._goods_amount = goods_amount

    @property
    def goods_value(self):
        """Gets the goods_value of this MerchandiseLine.  # noqa: E501

        Product value.  # noqa: E501

        :return: The goods_value of this MerchandiseLine.  # noqa: E501
        :rtype: float
        """
        return self._goods_value

    @goods_value.setter
    def goods_value(self, goods_value):
        """Sets the goods_value of this MerchandiseLine.

        Product value.  # noqa: E501

        :param goods_value: The goods_value of this MerchandiseLine.  # noqa: E501
        :type: float
        """
        if (self.local_vars_configuration.client_side_validation and
                goods_value is not None and goods_value < 0):  # noqa: E501
            raise ValueError("Invalid value for `goods_value`, must be a value greater than or equal to `0`")  # noqa: E501

        self._goods_value = goods_value

    @property
    def vat_rate(self):
        """Gets the vat_rate of this MerchandiseLine.  # noqa: E501

        Tax.  # noqa: E501

        :return: The vat_rate of this MerchandiseLine.  # noqa: E501
        :rtype: str
        """
        return self._vat_rate

    @vat_rate.setter
    def vat_rate(self, vat_rate):
        """Sets the vat_rate of this MerchandiseLine.

        Tax.  # noqa: E501

        :param vat_rate: The vat_rate of this MerchandiseLine.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and vat_rate is None:  # noqa: E501
            raise ValueError("Invalid value for `vat_rate`, must not be `None`")  # noqa: E501
        allowed_values = ["", "VAT0000", "VAT1000", "VAT1800", "VAT2000"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and vat_rate not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `vat_rate` ({0}), must be one of {1}"  # noqa: E501
                .format(vat_rate, allowed_values)
            )

        self._vat_rate = vat_rate

    @property
    def barcode(self):
        """Gets the barcode of this MerchandiseLine.  # noqa: E501

        Barcode.  # noqa: E501

        :return: The barcode of this MerchandiseLine.  # noqa: E501
        :rtype: str
        """
        return self._barcode

    @barcode.setter
    def barcode(self, barcode):
        """Sets the barcode of this MerchandiseLine.

        Barcode.  # noqa: E501

        :param barcode: The barcode of this MerchandiseLine.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                barcode is not None and len(barcode) > 1000):
            raise ValueError("Invalid value for `barcode`, length must be less than or equal to `1000`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                barcode is not None and len(barcode) < 1):
            raise ValueError("Invalid value for `barcode`, length must be greater than or equal to `1`")  # noqa: E501

        self._barcode = barcode

    @property
    def fact_time(self):
        """Gets the fact_time of this MerchandiseLine.  # noqa: E501

        Fact time in the [RFC 3339, section 5.6](https://tools.ietf.org/html/rfc3339#section-5.6) format.  # noqa: E501

        :return: The fact_time of this MerchandiseLine.  # noqa: E501
        :rtype: datetime
        """
        return self._fact_time

    @fact_time.setter
    def fact_time(self, fact_time):
        """Sets the fact_time of this MerchandiseLine.

        Fact time in the [RFC 3339, section 5.6](https://tools.ietf.org/html/rfc3339#section-5.6) format.  # noqa: E501

        :param fact_time: The fact_time of this MerchandiseLine.  # noqa: E501
        :type: datetime
        """

        self._fact_time = fact_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MerchandiseLine):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, MerchandiseLine):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    VeeRoute.UD

    VeeRoute.UD API  # noqa: E501

    The version of the OpenAPI document: 2.8.161005
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from vrt_ud.configuration import Configuration


class TrackPoint(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'latitude': 'float',
        'longitude': 'float',
        'timestamp': 'int'
    }

    attribute_map = {
        'latitude': 'latitude',
        'longitude': 'longitude',
        'timestamp': 'timestamp'
    }

    def __init__(self, latitude=None, longitude=None, timestamp=None, local_vars_configuration=None):  # noqa: E501
        """TrackPoint - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._latitude = None
        self._longitude = None
        self._timestamp = None
        self.discriminator = None

        self.latitude = latitude
        self.longitude = longitude
        self.timestamp = timestamp

    @property
    def latitude(self):
        """Gets the latitude of this TrackPoint.  # noqa: E501

        Latitude in degrees.  # noqa: E501

        :return: The latitude of this TrackPoint.  # noqa: E501
        :rtype: float
        """
        return self._latitude

    @latitude.setter
    def latitude(self, latitude):
        """Sets the latitude of this TrackPoint.

        Latitude in degrees.  # noqa: E501

        :param latitude: The latitude of this TrackPoint.  # noqa: E501
        :type: float
        """
        if self.local_vars_configuration.client_side_validation and latitude is None:  # noqa: E501
            raise ValueError("Invalid value for `latitude`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                latitude is not None and latitude > 90):  # noqa: E501
            raise ValueError("Invalid value for `latitude`, must be a value less than or equal to `90`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                latitude is not None and latitude < -90):  # noqa: E501
            raise ValueError("Invalid value for `latitude`, must be a value greater than or equal to `-90`")  # noqa: E501

        self._latitude = latitude

    @property
    def longitude(self):
        """Gets the longitude of this TrackPoint.  # noqa: E501

        Longitude in degrees.  # noqa: E501

        :return: The longitude of this TrackPoint.  # noqa: E501
        :rtype: float
        """
        return self._longitude

    @longitude.setter
    def longitude(self, longitude):
        """Sets the longitude of this TrackPoint.

        Longitude in degrees.  # noqa: E501

        :param longitude: The longitude of this TrackPoint.  # noqa: E501
        :type: float
        """
        if self.local_vars_configuration.client_side_validation and longitude is None:  # noqa: E501
            raise ValueError("Invalid value for `longitude`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                longitude is not None and longitude > 180):  # noqa: E501
            raise ValueError("Invalid value for `longitude`, must be a value less than or equal to `180`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                longitude is not None and longitude < -180):  # noqa: E501
            raise ValueError("Invalid value for `longitude`, must be a value greater than or equal to `-180`")  # noqa: E501

        self._longitude = longitude

    @property
    def timestamp(self):
        """Gets the timestamp of this TrackPoint.  # noqa: E501

        Time in the [UNIX](https://ru.wikipedia.org/wiki/Unix-%D0%B2%D1%80%D0%B5%D0%BC%D1%8F) format.  # noqa: E501

        :return: The timestamp of this TrackPoint.  # noqa: E501
        :rtype: int
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this TrackPoint.

        Time in the [UNIX](https://ru.wikipedia.org/wiki/Unix-%D0%B2%D1%80%D0%B5%D0%BC%D1%8F) format.  # noqa: E501

        :param timestamp: The timestamp of this TrackPoint.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and timestamp is None:  # noqa: E501
            raise ValueError("Invalid value for `timestamp`, must not be `None`")  # noqa: E501

        self._timestamp = timestamp

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TrackPoint):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TrackPoint):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    VeeRoute.UD

    VeeRoute.UD API  # noqa: E501

    The version of the OpenAPI document: 2.8.161005
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import vrt_ud
from vrt_ud.api.monitor_api import MonitorApi  # noqa: E501
from vrt_ud.rest import ApiException


class TestMonitorApi(unittest.TestCase):
    """MonitorApi unit test stubs"""

    def setUp(self):
        self.api = vrt_ud.api.monitor_api.MonitorApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_read_facts(self):
        """Test case for read_facts

        Getting the facts for a period of time  # noqa: E501
        """
        pass

    def test_read_performers(self):
        """Test case for read_performers

        Getting current information about the performer by filter.  # noqa: E501
        """
        pass

    def test_read_trips(self):
        """Test case for read_trips

        Getting the trips by filter.  # noqa: E501
        """
        pass

    def test_run_trips(self):
        """Test case for run_trips

        Trips launching.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    VeeRoute.UD

    VeeRoute.UD API  # noqa: E501

    The version of the OpenAPI document: 2.8.161005
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import vrt_ud
from vrt_ud.models.predictor_insert_task import PredictorInsertTask  # noqa: E501
from vrt_ud.rest import ApiException

class TestPredictorInsertTask(unittest.TestCase):
    """PredictorInsertTask unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PredictorInsertTask
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = vrt_ud.models.predictor_insert_task.PredictorInsertTask()  # noqa: E501
        if include_optional :
            return PredictorInsertTask(
                order = vrt_ud.models.order.Order(
                    key = 'order01', 
                    id = 'e47c94eb-4628-4b31-9180-c9c1dfa50ed1', 
                    state = 'PLAN', 
                    trip_id = 'e42c94eb-4628-4131-9180-c931dfa50ed1', 
                    trip_short_key = 'AFG', 
                    order_features = ["Special"], 
                    order_restrictions = ["Special"], 
                    performer_restrictions = ["B1"], 
                    cargos = [
                        vrt_ud.models.cargo.Cargo(
                            key = 'cargo01', 
                            capacity = vrt_ud.models.capacity.Capacity(
                                mass = 10, 
                                volume = 2, 
                                capacity_x = 1, 
                                capacity_y = 2, 
                                capacity_z = 3, ), 
                            width = 1, 
                            height = 0.3, 
                            length = 2.2, 
                            max_storage_time = 45, 
                            restrictions = ["Freezer"], )
                        ], 
                    demands = [
                        vrt_ud.models.demand.Demand(
                            key = 'demand01.1', 
                            demand_type = 'WORK', 
                            target_cargos = ["cargo01"], 
                            precedence_in_trip = 1, 
                            precedence_in_order = 1, 
                            possible_events = [
                                vrt_ud.models.possible_event.PossibleEvent(
                                    location_key = 'location01', 
                                    duration = 10, 
                                    reward = 199.9, 
                                    time_window = vrt_ud.models.time_window.TimeWindow(
                                        from = '2020-10-21T09:30+03:00', 
                                        to = '2020-10-21T19:45Z', ), )
                                ], )
                        ], ), 
                locations = [
                    vrt_ud.models.advanced_location.AdvancedLocation(
                        key = 'location01', 
                        location = vrt_ud.models.location.Location(
                            latitude = 55.692789, 
                            longitude = 37.554554, 
                            arrival_duration = 15, 
                            departure_duration = 5, ), 
                        transport_restrictions = ["2T"], 
                        load_windows = [
                            vrt_ud.models.load_window.LoadWindow(
                                time_window = vrt_ud.models.time_window.TimeWindow(
                                    from = '2020-10-21T09:30+03:00', 
                                    to = '2020-10-21T19:45Z', ), 
                                gates_count = 1, )
                            ], )
                    ], 
                max_cost = 3000, 
                allow_to_update_order = True
            )
        else :
            return PredictorInsertTask(
                order = vrt_ud.models.order.Order(
                    key = 'order01', 
                    id = 'e47c94eb-4628-4b31-9180-c9c1dfa50ed1', 
                    state = 'PLAN', 
                    trip_id = 'e42c94eb-4628-4131-9180-c931dfa50ed1', 
                    trip_short_key = 'AFG', 
                    order_features = ["Special"], 
                    order_restrictions = ["Special"], 
                    performer_restrictions = ["B1"], 
                    cargos = [
                        vrt_ud.models.cargo.Cargo(
                            key = 'cargo01', 
                            capacity = vrt_ud.models.capacity.Capacity(
                                mass = 10, 
                                volume = 2, 
                                capacity_x = 1, 
                                capacity_y = 2, 
                                capacity_z = 3, ), 
                            width = 1, 
                            height = 0.3, 
                            length = 2.2, 
                            max_storage_time = 45, 
                            restrictions = ["Freezer"], )
                        ], 
                    demands = [
                        vrt_ud.models.demand.Demand(
                            key = 'demand01.1', 
                            demand_type = 'WORK', 
                            target_cargos = ["cargo01"], 
                            precedence_in_trip = 1, 
                            precedence_in_order = 1, 
                            possible_events = [
                                vrt_ud.models.possible_event.PossibleEvent(
                                    location_key = 'location01', 
                                    duration = 10, 
                                    reward = 199.9, 
                                    time_window = vrt_ud.models.time_window.TimeWindow(
                                        from = '2020-10-21T09:30+03:00', 
                                        to = '2020-10-21T19:45Z', ), )
                                ], )
                        ], ),
                locations = [
                    vrt_ud.models.advanced_location.AdvancedLocation(
                        key = 'location01', 
                        location = vrt_ud.models.location.Location(
                            latitude = 55.692789, 
                            longitude = 37.554554, 
                            arrival_duration = 15, 
                            departure_duration = 5, ), 
                        transport_restrictions = ["2T"], 
                        load_windows = [
                            vrt_ud.models.load_window.LoadWindow(
                                time_window = vrt_ud.models.time_window.TimeWindow(
                                    from = '2020-10-21T09:30+03:00', 
                                    to = '2020-10-21T19:45Z', ), 
                                gates_count = 1, )
                            ], )
                    ],
                max_cost = 3000,
        )

    def testPredictorInsertTask(self):
        """Test PredictorInsertTask"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    VeeRoute.UD

    VeeRoute.UD API  # noqa: E501

    The version of the OpenAPI document: 2.8.161005
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from vrt_ud.configuration import Configuration


class Demand(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'key': 'str',
        'demand_type': 'str',
        'target_cargos': 'list[str]',
        'precedence_in_trip': 'int',
        'precedence_in_order': 'int',
        'possible_events': 'list[PossibleEvent]'
    }

    attribute_map = {
        'key': 'key',
        'demand_type': 'demand_type',
        'target_cargos': 'target_cargos',
        'precedence_in_trip': 'precedence_in_trip',
        'precedence_in_order': 'precedence_in_order',
        'possible_events': 'possible_events'
    }

    def __init__(self, key=None, demand_type=None, target_cargos=None, precedence_in_trip=0, precedence_in_order=0, possible_events=None, local_vars_configuration=None):  # noqa: E501
        """Demand - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._key = None
        self._demand_type = None
        self._target_cargos = None
        self._precedence_in_trip = None
        self._precedence_in_order = None
        self._possible_events = None
        self.discriminator = None

        self.key = key
        self.demand_type = demand_type
        if target_cargos is not None:
            self.target_cargos = target_cargos
        if precedence_in_trip is not None:
            self.precedence_in_trip = precedence_in_trip
        if precedence_in_order is not None:
            self.precedence_in_order = precedence_in_order
        self.possible_events = possible_events

    @property
    def key(self):
        """Gets the key of this Demand.  # noqa: E501

        Demand key, unique ID.  # noqa: E501

        :return: The key of this Demand.  # noqa: E501
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """Sets the key of this Demand.

        Demand key, unique ID.  # noqa: E501

        :param key: The key of this Demand.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and key is None:  # noqa: E501
            raise ValueError("Invalid value for `key`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                key is not None and len(key) > 1024):
            raise ValueError("Invalid value for `key`, length must be less than or equal to `1024`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                key is not None and len(key) < 1):
            raise ValueError("Invalid value for `key`, length must be greater than or equal to `1`")  # noqa: E501

        self._key = key

    @property
    def demand_type(self):
        """Gets the demand_type of this Demand.  # noqa: E501

        Demand type - loading (PICKUP, unloading (DROP, work at the location (WORK.  # noqa: E501

        :return: The demand_type of this Demand.  # noqa: E501
        :rtype: str
        """
        return self._demand_type

    @demand_type.setter
    def demand_type(self, demand_type):
        """Sets the demand_type of this Demand.

        Demand type - loading (PICKUP, unloading (DROP, work at the location (WORK.  # noqa: E501

        :param demand_type: The demand_type of this Demand.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and demand_type is None:  # noqa: E501
            raise ValueError("Invalid value for `demand_type`, must not be `None`")  # noqa: E501
        allowed_values = ["PICKUP", "DROP", "WORK"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and demand_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `demand_type` ({0}), must be one of {1}"  # noqa: E501
                .format(demand_type, allowed_values)
            )

        self._demand_type = demand_type

    @property
    def target_cargos(self):
        """Gets the target_cargos of this Demand.  # noqa: E501

        Cargo keys list for PICKUP, one cargo key for DROP, empty key for WORK.  # noqa: E501

        :return: The target_cargos of this Demand.  # noqa: E501
        :rtype: list[str]
        """
        return self._target_cargos

    @target_cargos.setter
    def target_cargos(self, target_cargos):
        """Sets the target_cargos of this Demand.

        Cargo keys list for PICKUP, one cargo key for DROP, empty key for WORK.  # noqa: E501

        :param target_cargos: The target_cargos of this Demand.  # noqa: E501
        :type: list[str]
        """

        self._target_cargos = target_cargos

    @property
    def precedence_in_trip(self):
        """Gets the precedence_in_trip of this Demand.  # noqa: E501

        Precedence in the trip, if 0 - precedence is not taken into account.  # noqa: E501

        :return: The precedence_in_trip of this Demand.  # noqa: E501
        :rtype: int
        """
        return self._precedence_in_trip

    @precedence_in_trip.setter
    def precedence_in_trip(self, precedence_in_trip):
        """Sets the precedence_in_trip of this Demand.

        Precedence in the trip, if 0 - precedence is not taken into account.  # noqa: E501

        :param precedence_in_trip: The precedence_in_trip of this Demand.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                precedence_in_trip is not None and precedence_in_trip < 0):  # noqa: E501
            raise ValueError("Invalid value for `precedence_in_trip`, must be a value greater than or equal to `0`")  # noqa: E501

        self._precedence_in_trip = precedence_in_trip

    @property
    def precedence_in_order(self):
        """Gets the precedence_in_order of this Demand.  # noqa: E501

        Precedence in the order, if 0 - precedence is not taken into account.  # noqa: E501

        :return: The precedence_in_order of this Demand.  # noqa: E501
        :rtype: int
        """
        return self._precedence_in_order

    @precedence_in_order.setter
    def precedence_in_order(self, precedence_in_order):
        """Sets the precedence_in_order of this Demand.

        Precedence in the order, if 0 - precedence is not taken into account.  # noqa: E501

        :param precedence_in_order: The precedence_in_order of this Demand.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                precedence_in_order is not None and precedence_in_order < 0):  # noqa: E501
            raise ValueError("Invalid value for `precedence_in_order`, must be a value greater than or equal to `0`")  # noqa: E501

        self._precedence_in_order = precedence_in_order

    @property
    def possible_events(self):
        """Gets the possible_events of this Demand.  # noqa: E501

        List of time windows and location keys, when and where it is possible to fulfil a demand.  # noqa: E501

        :return: The possible_events of this Demand.  # noqa: E501
        :rtype: list[PossibleEvent]
        """
        return self._possible_events

    @possible_events.setter
    def possible_events(self, possible_events):
        """Sets the possible_events of this Demand.

        List of time windows and location keys, when and where it is possible to fulfil a demand.  # noqa: E501

        :param possible_events: The possible_events of this Demand.  # noqa: E501
        :type: list[PossibleEvent]
        """
        if self.local_vars_configuration.client_side_validation and possible_events is None:  # noqa: E501
            raise ValueError("Invalid value for `possible_events`, must not be `None`")  # noqa: E501

        self._possible_events = possible_events

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Demand):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Demand):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    VeeRoute.UD

    VeeRoute.UD API  # noqa: E501

    The version of the OpenAPI document: 2.8.161005
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import vrt_ud
from vrt_ud.api.data_api import DataApi  # noqa: E501
from vrt_ud.rest import ApiException


class TestDataApi(unittest.TestCase):
    """DataApi unit test stubs"""

    def setUp(self):
        self.api = vrt_ud.api.data_api.DataApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_clean_data(self):
        """Test case for clean_data

        Removing the data for a period of time.  # noqa: E501
        """
        pass

    def test_download_photo(self):
        """Test case for download_photo

        Downloading the photo by ID.  # noqa: E501
        """
        pass

    def test_find_photos(self):
        """Test case for find_photos

        Getting the photo IDs by filter.  # noqa: E501
        """
        pass

    def test_load_data(self):
        """Test case for load_data

        Loading the data from file in the form of base64 line.  # noqa: E501
        """
        pass

    def test_load_data_file(self):
        """Test case for load_data_file

        Data loading from a file.  # noqa: E501
        """
        pass

    def test_read_orders(self):
        """Test case for read_orders

        Getting the order by filter.  # noqa: E501
        """
        pass

    def test_remove_orders(self):
        """Test case for remove_orders

        Removing the orders by filter.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    VeeRoute.UD

    VeeRoute.UD API  # noqa: E501

    The version of the OpenAPI document: 2.8.161005
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from vrt_ud.configuration import Configuration


class Cargo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'key': 'str',
        'capacity': 'Capacity',
        'width': 'float',
        'height': 'float',
        'length': 'float',
        'max_storage_time': 'int',
        'restrictions': 'list[str]'
    }

    attribute_map = {
        'key': 'key',
        'capacity': 'capacity',
        'width': 'width',
        'height': 'height',
        'length': 'length',
        'max_storage_time': 'max_storage_time',
        'restrictions': 'restrictions'
    }

    def __init__(self, key=None, capacity=None, width=0, height=0, length=0, max_storage_time=43800, restrictions=None, local_vars_configuration=None):  # noqa: E501
        """Cargo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._key = None
        self._capacity = None
        self._width = None
        self._height = None
        self._length = None
        self._max_storage_time = None
        self._restrictions = None
        self.discriminator = None

        self.key = key
        self.capacity = capacity
        if width is not None:
            self.width = width
        if height is not None:
            self.height = height
        if length is not None:
            self.length = length
        if max_storage_time is not None:
            self.max_storage_time = max_storage_time
        if restrictions is not None:
            self.restrictions = restrictions

    @property
    def key(self):
        """Gets the key of this Cargo.  # noqa: E501

        Cargo key, unique ID.  # noqa: E501

        :return: The key of this Cargo.  # noqa: E501
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """Sets the key of this Cargo.

        Cargo key, unique ID.  # noqa: E501

        :param key: The key of this Cargo.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and key is None:  # noqa: E501
            raise ValueError("Invalid value for `key`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                key is not None and len(key) > 1024):
            raise ValueError("Invalid value for `key`, length must be less than or equal to `1024`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                key is not None and len(key) < 1):
            raise ValueError("Invalid value for `key`, length must be greater than or equal to `1`")  # noqa: E501

        self._key = key

    @property
    def capacity(self):
        """Gets the capacity of this Cargo.  # noqa: E501


        :return: The capacity of this Cargo.  # noqa: E501
        :rtype: Capacity
        """
        return self._capacity

    @capacity.setter
    def capacity(self, capacity):
        """Sets the capacity of this Cargo.


        :param capacity: The capacity of this Cargo.  # noqa: E501
        :type: Capacity
        """

        self._capacity = capacity

    @property
    def width(self):
        """Gets the width of this Cargo.  # noqa: E501

        Width in meters, used to check the cargo and compartment compatibility.  # noqa: E501

        :return: The width of this Cargo.  # noqa: E501
        :rtype: float
        """
        return self._width

    @width.setter
    def width(self, width):
        """Sets the width of this Cargo.

        Width in meters, used to check the cargo and compartment compatibility.  # noqa: E501

        :param width: The width of this Cargo.  # noqa: E501
        :type: float
        """
        if (self.local_vars_configuration.client_side_validation and
                width is not None and width < 0):  # noqa: E501
            raise ValueError("Invalid value for `width`, must be a value greater than or equal to `0`")  # noqa: E501

        self._width = width

    @property
    def height(self):
        """Gets the height of this Cargo.  # noqa: E501

        Height in meters, used to check the cargo and compartment compatibility.  # noqa: E501

        :return: The height of this Cargo.  # noqa: E501
        :rtype: float
        """
        return self._height

    @height.setter
    def height(self, height):
        """Sets the height of this Cargo.

        Height in meters, used to check the cargo and compartment compatibility.  # noqa: E501

        :param height: The height of this Cargo.  # noqa: E501
        :type: float
        """
        if (self.local_vars_configuration.client_side_validation and
                height is not None and height < 0):  # noqa: E501
            raise ValueError("Invalid value for `height`, must be a value greater than or equal to `0`")  # noqa: E501

        self._height = height

    @property
    def length(self):
        """Gets the length of this Cargo.  # noqa: E501

        Length in meters, used to check the cargo and compartment compatibility.  # noqa: E501

        :return: The length of this Cargo.  # noqa: E501
        :rtype: float
        """
        return self._length

    @length.setter
    def length(self, length):
        """Sets the length of this Cargo.

        Length in meters, used to check the cargo and compartment compatibility.  # noqa: E501

        :param length: The length of this Cargo.  # noqa: E501
        :type: float
        """
        if (self.local_vars_configuration.client_side_validation and
                length is not None and length < 0):  # noqa: E501
            raise ValueError("Invalid value for `length`, must be a value greater than or equal to `0`")  # noqa: E501

        self._length = length

    @property
    def max_storage_time(self):
        """Gets the max_storage_time of this Cargo.  # noqa: E501

        Maximum storage time inside a compartment, in minutes. If not specified, the limit is not taken into account.   # noqa: E501

        :return: The max_storage_time of this Cargo.  # noqa: E501
        :rtype: int
        """
        return self._max_storage_time

    @max_storage_time.setter
    def max_storage_time(self, max_storage_time):
        """Sets the max_storage_time of this Cargo.

        Maximum storage time inside a compartment, in minutes. If not specified, the limit is not taken into account.   # noqa: E501

        :param max_storage_time: The max_storage_time of this Cargo.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                max_storage_time is not None and max_storage_time > 43800):  # noqa: E501
            raise ValueError("Invalid value for `max_storage_time`, must be a value less than or equal to `43800`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                max_storage_time is not None and max_storage_time < 0):  # noqa: E501
            raise ValueError("Invalid value for `max_storage_time`, must be a value greater than or equal to `0`")  # noqa: E501

        self._max_storage_time = max_storage_time

    @property
    def restrictions(self):
        """Gets the restrictions of this Cargo.  # noqa: E501

        List of requirements to a compartment to carry a cargo.  # noqa: E501

        :return: The restrictions of this Cargo.  # noqa: E501
        :rtype: list[str]
        """
        return self._restrictions

    @restrictions.setter
    def restrictions(self, restrictions):
        """Sets the restrictions of this Cargo.

        List of requirements to a compartment to carry a cargo.  # noqa: E501

        :param restrictions: The restrictions of this Cargo.  # noqa: E501
        :type: list[str]
        """

        self._restrictions = restrictions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Cargo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Cargo):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    VeeRoute.UD

    VeeRoute.UD API  # noqa: E501

    The version of the OpenAPI document: 2.8.161005
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from vrt_ud.configuration import Configuration


class PredictorCheckResult(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'currently_started_data_preparation': 'datetime',
        'previous_data_preparation': 'datetime',
        'last_succesful_data_preparation': 'datetime',
        'validation_result': 'str',
        'current_data_preparation_errors': 'str',
        'last_owp_validation_errors': 'str'
    }

    attribute_map = {
        'currently_started_data_preparation': 'currently_started_data_preparation',
        'previous_data_preparation': 'previous_data_preparation',
        'last_succesful_data_preparation': 'last_succesful_data_preparation',
        'validation_result': 'validation_result',
        'current_data_preparation_errors': 'current_data_preparation_errors',
        'last_owp_validation_errors': 'last_owp_validation_errors'
    }

    def __init__(self, currently_started_data_preparation=None, previous_data_preparation=None, last_succesful_data_preparation=None, validation_result=None, current_data_preparation_errors=None, last_owp_validation_errors=None, local_vars_configuration=None):  # noqa: E501
        """PredictorCheckResult - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._currently_started_data_preparation = None
        self._previous_data_preparation = None
        self._last_succesful_data_preparation = None
        self._validation_result = None
        self._current_data_preparation_errors = None
        self._last_owp_validation_errors = None
        self.discriminator = None

        if currently_started_data_preparation is not None:
            self.currently_started_data_preparation = currently_started_data_preparation
        if previous_data_preparation is not None:
            self.previous_data_preparation = previous_data_preparation
        if last_succesful_data_preparation is not None:
            self.last_succesful_data_preparation = last_succesful_data_preparation
        if validation_result is not None:
            self.validation_result = validation_result
        if current_data_preparation_errors is not None:
            self.current_data_preparation_errors = current_data_preparation_errors
        if last_owp_validation_errors is not None:
            self.last_owp_validation_errors = last_owp_validation_errors

    @property
    def currently_started_data_preparation(self):
        """Gets the currently_started_data_preparation of this PredictorCheckResult.  # noqa: E501

        Time of the last scenario start.  # noqa: E501

        :return: The currently_started_data_preparation of this PredictorCheckResult.  # noqa: E501
        :rtype: datetime
        """
        return self._currently_started_data_preparation

    @currently_started_data_preparation.setter
    def currently_started_data_preparation(self, currently_started_data_preparation):
        """Sets the currently_started_data_preparation of this PredictorCheckResult.

        Time of the last scenario start.  # noqa: E501

        :param currently_started_data_preparation: The currently_started_data_preparation of this PredictorCheckResult.  # noqa: E501
        :type: datetime
        """

        self._currently_started_data_preparation = currently_started_data_preparation

    @property
    def previous_data_preparation(self):
        """Gets the previous_data_preparation of this PredictorCheckResult.  # noqa: E501

        Time of the previous scenario start.  # noqa: E501

        :return: The previous_data_preparation of this PredictorCheckResult.  # noqa: E501
        :rtype: datetime
        """
        return self._previous_data_preparation

    @previous_data_preparation.setter
    def previous_data_preparation(self, previous_data_preparation):
        """Sets the previous_data_preparation of this PredictorCheckResult.

        Time of the previous scenario start.  # noqa: E501

        :param previous_data_preparation: The previous_data_preparation of this PredictorCheckResult.  # noqa: E501
        :type: datetime
        """

        self._previous_data_preparation = previous_data_preparation

    @property
    def last_succesful_data_preparation(self):
        """Gets the last_succesful_data_preparation of this PredictorCheckResult.  # noqa: E501

        Time of the last successful scenario playback.  # noqa: E501

        :return: The last_succesful_data_preparation of this PredictorCheckResult.  # noqa: E501
        :rtype: datetime
        """
        return self._last_succesful_data_preparation

    @last_succesful_data_preparation.setter
    def last_succesful_data_preparation(self, last_succesful_data_preparation):
        """Sets the last_succesful_data_preparation of this PredictorCheckResult.

        Time of the last successful scenario playback.  # noqa: E501

        :param last_succesful_data_preparation: The last_succesful_data_preparation of this PredictorCheckResult.  # noqa: E501
        :type: datetime
        """

        self._last_succesful_data_preparation = last_succesful_data_preparation

    @property
    def validation_result(self):
        """Gets the validation_result of this PredictorCheckResult.  # noqa: E501

        Data validation result from the last scenario launching.  # noqa: E501

        :return: The validation_result of this PredictorCheckResult.  # noqa: E501
        :rtype: str
        """
        return self._validation_result

    @validation_result.setter
    def validation_result(self, validation_result):
        """Sets the validation_result of this PredictorCheckResult.

        Data validation result from the last scenario launching.  # noqa: E501

        :param validation_result: The validation_result of this PredictorCheckResult.  # noqa: E501
        :type: str
        """

        self._validation_result = validation_result

    @property
    def current_data_preparation_errors(self):
        """Gets the current_data_preparation_errors of this PredictorCheckResult.  # noqa: E501

        Errors in the last scenario launching.  # noqa: E501

        :return: The current_data_preparation_errors of this PredictorCheckResult.  # noqa: E501
        :rtype: str
        """
        return self._current_data_preparation_errors

    @current_data_preparation_errors.setter
    def current_data_preparation_errors(self, current_data_preparation_errors):
        """Sets the current_data_preparation_errors of this PredictorCheckResult.

        Errors in the last scenario launching.  # noqa: E501

        :param current_data_preparation_errors: The current_data_preparation_errors of this PredictorCheckResult.  # noqa: E501
        :type: str
        """

        self._current_data_preparation_errors = current_data_preparation_errors

    @property
    def last_owp_validation_errors(self):
        """Gets the last_owp_validation_errors of this PredictorCheckResult.  # noqa: E501

        Errors in the previous scenario launching.  # noqa: E501

        :return: The last_owp_validation_errors of this PredictorCheckResult.  # noqa: E501
        :rtype: str
        """
        return self._last_owp_validation_errors

    @last_owp_validation_errors.setter
    def last_owp_validation_errors(self, last_owp_validation_errors):
        """Sets the last_owp_validation_errors of this PredictorCheckResult.

        Errors in the previous scenario launching.  # noqa: E501

        :param last_owp_validation_errors: The last_owp_validation_errors of this PredictorCheckResult.  # noqa: E501
        :type: str
        """

        self._last_owp_validation_errors = last_owp_validation_errors

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PredictorCheckResult):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PredictorCheckResult):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    VeeRoute.UD

    VeeRoute.UD API  # noqa: E501

    The version of the OpenAPI document: 2.8.161005
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from vrt_ud.api_client import ApiClient
from vrt_ud.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class DataApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def clean_data(self, delete_filter, **kwargs):  # noqa: E501
        """Removing the data for a period of time.  # noqa: E501

        Removing the data for a period of time.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.clean_data(delete_filter, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param DeleteFilter delete_filter: Request filter for data removal. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.clean_data_with_http_info(delete_filter, **kwargs)  # noqa: E501

    def clean_data_with_http_info(self, delete_filter, **kwargs):  # noqa: E501
        """Removing the data for a period of time.  # noqa: E501

        Removing the data for a period of time.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.clean_data_with_http_info(delete_filter, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param DeleteFilter delete_filter: Request filter for data removal. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'delete_filter'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method clean_data" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'delete_filter' is set
        if self.api_client.client_side_validation and ('delete_filter' not in local_var_params or  # noqa: E501
                                                        local_var_params['delete_filter'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `delete_filter` when calling `clean_data`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'delete_filter' in local_var_params:
            body_params = local_var_params['delete_filter']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['ApiKeyAuth']  # noqa: E501

        return self.api_client.call_api(
            '/data', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def download_photo(self, id, **kwargs):  # noqa: E501
        """Downloading the photo by ID.  # noqa: E501

        Downloading the photo by ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.download_photo(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.download_photo_with_http_info(id, **kwargs)  # noqa: E501

    def download_photo_with_http_info(self, id, **kwargs):  # noqa: E501
        """Downloading the photo by ID.  # noqa: E501

        Downloading the photo by ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.download_photo_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(str, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method download_photo" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `download_photo`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/octet-stream', 'application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['ApiKeyAuth']  # noqa: E501

        return self.api_client.call_api(
            '/photos/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def find_photos(self, photos_filter, **kwargs):  # noqa: E501
        """Getting the photo IDs by filter.  # noqa: E501

        Getting the photo IDs by filter.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_photos(photos_filter, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param PhotosFilter photos_filter: Photo IDs filter. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[str]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.find_photos_with_http_info(photos_filter, **kwargs)  # noqa: E501

    def find_photos_with_http_info(self, photos_filter, **kwargs):  # noqa: E501
        """Getting the photo IDs by filter.  # noqa: E501

        Getting the photo IDs by filter.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_photos_with_http_info(photos_filter, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param PhotosFilter photos_filter: Photo IDs filter. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[str], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'photos_filter'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method find_photos" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'photos_filter' is set
        if self.api_client.client_side_validation and ('photos_filter' not in local_var_params or  # noqa: E501
                                                        local_var_params['photos_filter'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `photos_filter` when calling `find_photos`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'photos_filter' in local_var_params:
            body_params = local_var_params['photos_filter']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['ApiKeyAuth']  # noqa: E501

        return self.api_client.call_api(
            '/photos/find', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[str]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def load_data(self, data_load_task, **kwargs):  # noqa: E501
        """Loading the data from file in the form of base64 line.  # noqa: E501

        Loading the data from json\\XLSX file in the form of base64 line.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.load_data(data_load_task, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param DataLoadTask data_load_task: New data loading request. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.load_data_with_http_info(data_load_task, **kwargs)  # noqa: E501

    def load_data_with_http_info(self, data_load_task, **kwargs):  # noqa: E501
        """Loading the data from file in the form of base64 line.  # noqa: E501

        Loading the data from json\\XLSX file in the form of base64 line.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.load_data_with_http_info(data_load_task, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param DataLoadTask data_load_task: New data loading request. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'data_load_task'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method load_data" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'data_load_task' is set
        if self.api_client.client_side_validation and ('data_load_task' not in local_var_params or  # noqa: E501
                                                        local_var_params['data_load_task'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `data_load_task` when calling `load_data`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'data_load_task' in local_var_params:
            body_params = local_var_params['data_load_task']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['ApiKeyAuth']  # noqa: E501

        return self.api_client.call_api(
            '/data', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def load_data_file(self, file, **kwargs):  # noqa: E501
        """Data loading from a file.  # noqa: E501

        Data loading from a json\\XLSX file.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.load_data_file(file, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param file file: File contents. (required)
        :param int time_shift_hours: The times in the data will be shifted during loading for the specified time period in hours, and both positive and negative values are accepted.
        :param bool save: Save the file after uploading to the server.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.load_data_file_with_http_info(file, **kwargs)  # noqa: E501

    def load_data_file_with_http_info(self, file, **kwargs):  # noqa: E501
        """Data loading from a file.  # noqa: E501

        Data loading from a json\\XLSX file.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.load_data_file_with_http_info(file, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param file file: File contents. (required)
        :param int time_shift_hours: The times in the data will be shifted during loading for the specified time period in hours, and both positive and negative values are accepted.
        :param bool save: Save the file after uploading to the server.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'file',
            'time_shift_hours',
            'save'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method load_data_file" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'file' is set
        if self.api_client.client_side_validation and ('file' not in local_var_params or  # noqa: E501
                                                        local_var_params['file'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `file` when calling `load_data_file`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'file' in local_var_params:
            local_var_files['file'] = local_var_params['file']  # noqa: E501
        if 'time_shift_hours' in local_var_params:
            form_params.append(('time_shift_hours', local_var_params['time_shift_hours']))  # noqa: E501
        if 'save' in local_var_params:
            form_params.append(('save', local_var_params['save']))  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['ApiKeyAuth']  # noqa: E501

        return self.api_client.call_api(
            '/data/file', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def read_orders(self, orders_filter, **kwargs):  # noqa: E501
        """Getting the order by filter.  # noqa: E501

        Getting the order by filter.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.read_orders(orders_filter, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param OrdersFilter orders_filter: Orders filter. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: OrdersResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.read_orders_with_http_info(orders_filter, **kwargs)  # noqa: E501

    def read_orders_with_http_info(self, orders_filter, **kwargs):  # noqa: E501
        """Getting the order by filter.  # noqa: E501

        Getting the order by filter.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.read_orders_with_http_info(orders_filter, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param OrdersFilter orders_filter: Orders filter. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(OrdersResult, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'orders_filter'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method read_orders" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'orders_filter' is set
        if self.api_client.client_side_validation and ('orders_filter' not in local_var_params or  # noqa: E501
                                                        local_var_params['orders_filter'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `orders_filter` when calling `read_orders`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'orders_filter' in local_var_params:
            body_params = local_var_params['orders_filter']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['ApiKeyAuth']  # noqa: E501

        return self.api_client.call_api(
            '/data/orders', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='OrdersResult',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_orders(self, orders_filter, **kwargs):  # noqa: E501
        """Removing the orders by filter.  # noqa: E501

        Safe removing the orders by filter.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_orders(orders_filter, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param OrdersFilter orders_filter: Orders filter. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.remove_orders_with_http_info(orders_filter, **kwargs)  # noqa: E501

    def remove_orders_with_http_info(self, orders_filter, **kwargs):  # noqa: E501
        """Removing the orders by filter.  # noqa: E501

        Safe removing the orders by filter.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_orders_with_http_info(orders_filter, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param OrdersFilter orders_filter: Orders filter. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'orders_filter'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_orders" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'orders_filter' is set
        if self.api_client.client_side_validation and ('orders_filter' not in local_var_params or  # noqa: E501
                                                        local_var_params['orders_filter'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `orders_filter` when calling `remove_orders`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'orders_filter' in local_var_params:
            body_params = local_var_params['orders_filter']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['ApiKeyAuth']  # noqa: E501

        return self.api_client.call_api(
            '/data/orders', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    VeeRoute.UD

    VeeRoute.UD API  # noqa: E501

    The version of the OpenAPI document: 2.8.161005
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from vrt_ud.configuration import Configuration


class TripsFilter(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'time_window': 'TimeWindow',
        'state': 'str',
        'zone': 'str',
        'keys': 'list[str]'
    }

    attribute_map = {
        'time_window': 'time_window',
        'state': 'state',
        'zone': 'zone',
        'keys': 'keys'
    }

    def __init__(self, time_window=None, state=None, zone=None, keys=None, local_vars_configuration=None):  # noqa: E501
        """TripsFilter - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._time_window = None
        self._state = None
        self._zone = None
        self._keys = None
        self.discriminator = None

        if time_window is not None:
            self.time_window = time_window
        if state is not None:
            self.state = state
        if zone is not None:
            self.zone = zone
        if keys is not None:
            self.keys = keys

    @property
    def time_window(self):
        """Gets the time_window of this TripsFilter.  # noqa: E501


        :return: The time_window of this TripsFilter.  # noqa: E501
        :rtype: TimeWindow
        """
        return self._time_window

    @time_window.setter
    def time_window(self, time_window):
        """Sets the time_window of this TripsFilter.


        :param time_window: The time_window of this TripsFilter.  # noqa: E501
        :type: TimeWindow
        """

        self._time_window = time_window

    @property
    def state(self):
        """Gets the state of this TripsFilter.  # noqa: E501

        Trips state.  # noqa: E501

        :return: The state of this TripsFilter.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this TripsFilter.

        Trips state.  # noqa: E501

        :param state: The state of this TripsFilter.  # noqa: E501
        :type: str
        """
        allowed_values = ["PLAN", "EXEC", "EXPIRE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and state not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `state` ({0}), must be one of {1}"  # noqa: E501
                .format(state, allowed_values)
            )

        self._state = state

    @property
    def zone(self):
        """Gets the zone of this TripsFilter.  # noqa: E501

        Trip zone.  # noqa: E501

        :return: The zone of this TripsFilter.  # noqa: E501
        :rtype: str
        """
        return self._zone

    @zone.setter
    def zone(self, zone):
        """Sets the zone of this TripsFilter.

        Trip zone.  # noqa: E501

        :param zone: The zone of this TripsFilter.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                zone is not None and len(zone) > 256):
            raise ValueError("Invalid value for `zone`, length must be less than or equal to `256`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                zone is not None and len(zone) < 1):
            raise ValueError("Invalid value for `zone`, length must be greater than or equal to `1`")  # noqa: E501

        self._zone = zone

    @property
    def keys(self):
        """Gets the keys of this TripsFilter.  # noqa: E501

        Trip keys list.  # noqa: E501

        :return: The keys of this TripsFilter.  # noqa: E501
        :rtype: list[str]
        """
        return self._keys

    @keys.setter
    def keys(self, keys):
        """Sets the keys of this TripsFilter.

        Trip keys list.  # noqa: E501

        :param keys: The keys of this TripsFilter.  # noqa: E501
        :type: list[str]
        """

        self._keys = keys

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TripsFilter):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TripsFilter):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    VeeRoute.UD

    VeeRoute.UD API  # noqa: E501

    The version of the OpenAPI document: 2.8.161005
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import vrt_ud
from vrt_ud.models.facts_result import FactsResult  # noqa: E501
from vrt_ud.rest import ApiException

class TestFactsResult(unittest.TestCase):
    """FactsResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test FactsResult
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = vrt_ud.models.facts_result.FactsResult()  # noqa: E501
        if include_optional :
            return FactsResult(
                job_done = [
                    vrt_ud.models.fact_job_done.FactJobDone(
                        performer_id = 'f_887', 
                        trip_id = 'default', 
                        order_id = 'default', 
                        demand_key = 'default', 
                        job_number = 1, 
                        job_name = 'default', 
                        message = 'default', 
                        storage_server_file_ids = [
                            'fileid'
                            ], 
                        fact_time = '2020-10-21T09:30+03:00', )
                    ], 
                demand_done = [
                    vrt_ud.models.fact_demand_done.FactDemandDone(
                        performer_id = 'f_887', 
                        trip_id = 'default', 
                        order_id = 'default', 
                        demand_key = 'default', 
                        merchandise_lines = [
                            vrt_ud.models.merchandise_line.MerchandiseLine(
                                goods_name = 'boxes', 
                                goods_unit_name = 'box', 
                                goods_unit_price = 500, 
                                goods_amount = 2, 
                                goods_value = 1000, 
                                vat_rate = 'VAT0000', 
                                barcode = 'default', 
                                fact_time = '2020-10-21T09:30+03:00', )
                            ], 
                        cancellations = [
                            vrt_ud.models.order_cancellation.OrderCancellation(
                                goods_name = 'boxes', 
                                goods_amount = 2, 
                                cancellation_reason = 'no reason', 
                                fact_time = '2020-10-21T09:30+03:00', )
                            ], 
                        fact_time = '2020-10-21T09:30+03:00', )
                    ], 
                demand_cancellation = [
                    vrt_ud.models.fact_demand_cancellation.FactDemandCancellation(
                        performer_id = 'f_887', 
                        trip_id = 'default', 
                        order_id = 'default', 
                        demand_key = 'default', 
                        cancellation_reason = 'no reason', 
                        fact_time = '2020-10-21T09:30+03:00', )
                    ], 
                demand_payment = [
                    vrt_ud.models.fact_demand_payment.FactDemandPayment(
                        performer_id = 'f_887', 
                        trip_id = 'default', 
                        order_id = 'default', 
                        demand_key = 'default', 
                        payment_details = vrt_ud.models.payment_details.PaymentDetails(
                            bill_number_in_shift = '1', 
                            bill_date_time = 'default', 
                            customer_email = 'customer@company.com', 
                            bill_amount_total = 1000, 
                            fd_number = 'default', 
                            fn_number = 'default', 
                            qr_code = 'default', 
                            payment_type = 'default', 
                            approval_code = 'default', 
                            kkt_registration_number = 'default', 
                            invoice = 'default', 
                            f_mark = 'default', 
                            f_shift = 'default', 
                            handmade_prepayment = 1000, 
                            merchandise_lines = [
                                vrt_ud.models.merchandise_line.MerchandiseLine(
                                    goods_name = 'boxes', 
                                    goods_unit_name = 'box', 
                                    goods_unit_price = 500, 
                                    goods_amount = 2, 
                                    goods_value = 1000, 
                                    vat_rate = 'VAT0000', 
                                    barcode = 'default', 
                                    fact_time = '2020-10-21T09:30+03:00', )
                                ], ), 
                        fact_time = '2020-10-21T09:30+03:00', )
                    ], 
                demand_resumed = [
                    vrt_ud.models.fact_demand_resumed.FactDemandResumed(
                        performer_id = 'f_887', 
                        trip_id = 'default', 
                        order_id = 'default', 
                        demand_key = 'default', 
                        fact_time = '2020-10-21T09:30+03:00', )
                    ], 
                event_window_changed = [
                    vrt_ud.models.fact_event_window_changed.FactEventWindowChanged(
                        performer_id = 'f_887', 
                        trip_id = 'default', 
                        order_id = 'default', 
                        demand_key = 'default', 
                        location_id = 'default', 
                        old_hard_time_from = '2020-10-21T09:30+03:00', 
                        old_hard_time_to = '2020-10-21T09:30+03:00', 
                        old_soft_time_from = '2020-10-21T09:30+03:00', 
                        old_soft_time_to = '2020-10-21T09:30+03:00', 
                        new_hard_time_from = '2020-10-21T09:30+03:00', 
                        new_hard_time_to = '2020-10-21T09:30+03:00', 
                        new_soft_time_from = '2020-10-21T09:30+03:00', 
                        new_soft_time_to = '2020-10-21T09:30+03:00', 
                        window_change_reason = 'no reason', 
                        fact_time = '2020-10-21T09:30+03:00', )
                    ], 
                performer_message = [
                    vrt_ud.models.fact_performer_message.FactPerformerMessage(
                        performer_id = 'f_887', 
                        trip_id = 'default', 
                        transport_id = 'default', 
                        message_topic = 'default', 
                        message = 'default', 
                        storage_server_file_ids = [
                            'fileid'
                            ], 
                        fact_time = '2020-10-21T09:30+03:00', )
                    ], 
                trip_status_notice = [
                    vrt_ud.models.fact_trip_status_notice.FactTripStatusNotice(
                        performer_id = 'f_887', 
                        trip_id = 'default', 
                        name = 'RECEIVED', 
                        fact_time = '2020-10-21T09:30+03:00', )
                    ], 
                tripaction_comment_changed = [
                    vrt_ud.models.fact_tripaction_comment_changed.FactTripactionCommentChanged(
                        performer_id = 'f_887', 
                        trip_id = 'default', 
                        order_id = 'default', 
                        demand_key = 'default', 
                        old_comment_value = 'default', 
                        new_comment_value = 'default', 
                        fact_time = '2020-10-21T09:30+03:00', )
                    ], 
                work_started = [
                    vrt_ud.models.fact_work_started.FactWorkStarted(
                        performer_id = 'f_887', 
                        trip_id = 'default', 
                        order_id = 'default', 
                        demand_key = 'default', 
                        fact_time = '2020-10-21T09:30+03:00', )
                    ], 
                trip_progress = [
                    vrt_ud.models.fact_trip_progress.FactTripProgress(
                        trip_id = 'default', 
                        executed_orders_in_trip = 0.3, 
                        executed_orders_for_current_time = 1.2, 
                        fact_time = '2020-10-21T09:30+03:00', )
                    ], 
                photo = [
                    vrt_ud.models.fact_photo.FactPhoto(
                        performer_id = 'f_887', 
                        trip_id = 'default', 
                        order_id = 'default', 
                        demand_key = 'default', 
                        message = 'default', 
                        storage_server_file_id = 'fileid', 
                        fact_time = '2020-10-21T09:30+03:00', )
                    ]
            )
        else :
            return FactsResult(
        )

    def testFactsResult(self):
        """Test FactsResult"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    VeeRoute.UD

    VeeRoute.UD API  # noqa: E501

    The version of the OpenAPI document: 2.8.161005
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


from setuptools import setup, find_packages  # noqa: H301

NAME = "vrt_ud"
VERSION = "2.8.161005"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"]

setup(
    name=NAME,
    version=VERSION,
    description="VeeRoute.UD",
    author="VeeRoute Support Team",
    author_email="support@veeroute.com",
    url="https://docs.veeroute.com/#/udl/integration/openapi",
    keywords=["OpenAPI", "OpenAPI-Generator", "VeeRoute.UD"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    long_description="""\
    VeeRoute.UD API  # noqa: E501
    """
)



# coding: utf-8

"""
    VeeRoute.UD

    VeeRoute.UD API  # noqa: E501

    The version of the OpenAPI document: 2.8.161005
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import vrt_ud
from vrt_ud.models.orders_result import OrdersResult  # noqa: E501
from vrt_ud.rest import ApiException

class TestOrdersResult(unittest.TestCase):
    """OrdersResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test OrdersResult
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = vrt_ud.models.orders_result.OrdersResult()  # noqa: E501
        if include_optional :
            return OrdersResult(
                orders = [
                    vrt_ud.models.order.Order(
                        key = 'order01', 
                        id = 'e47c94eb-4628-4b31-9180-c9c1dfa50ed1', 
                        state = 'PLAN', 
                        trip_id = 'e42c94eb-4628-4131-9180-c931dfa50ed1', 
                        trip_short_key = 'AFG', 
                        order_features = ["Special"], 
                        order_restrictions = ["Special"], 
                        performer_restrictions = ["B1"], 
                        cargos = [
                            vrt_ud.models.cargo.Cargo(
                                key = 'cargo01', 
                                capacity = vrt_ud.models.capacity.Capacity(
                                    mass = 10, 
                                    volume = 2, 
                                    capacity_x = 1, 
                                    capacity_y = 2, 
                                    capacity_z = 3, ), 
                                width = 1, 
                                height = 0.3, 
                                length = 2.2, 
                                max_storage_time = 45, 
                                restrictions = ["Freezer"], )
                            ], 
                        demands = [
                            vrt_ud.models.demand.Demand(
                                key = 'demand01.1', 
                                demand_type = 'WORK', 
                                target_cargos = ["cargo01"], 
                                precedence_in_trip = 1, 
                                precedence_in_order = 1, 
                                possible_events = [
                                    vrt_ud.models.possible_event.PossibleEvent(
                                        location_key = 'location01', 
                                        duration = 10, 
                                        reward = 199.9, 
                                        time_window = vrt_ud.models.time_window.TimeWindow(
                                            from = '2020-10-21T09:30+03:00', 
                                            to = '2020-10-21T19:45Z', ), )
                                    ], )
                            ], )
                    ]
            )
        else :
            return OrdersResult(
        )

    def testOrdersResult(self):
        """Test OrdersResult"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
